==> vue-sb-components-2.3.9.tgz: package/components/form-radio/form-radio.js <==
import "./form-radio.css";
import { defineComponent as p, openBlock as s, createElementBlock as r, mergeProps as c, normalizeClass as d, createElementVNode as t, toDisplayString as n, createCommentVNode as i, Fragment as h, renderList as y, pushScopeId as f, popScopeId as m } from "vue";
import { _ as b } from "../../_plugin-vue_export-helper-dad06003.js";
const g = p({
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    input: (e) => !0
  },
  props: {
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    isError: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    list: {
      required: !0,
      type: Object
    },
    modelValue: {
      required: !1,
      type: Object
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    value: {
      required: !1,
      type: Object
    }
  },
  name: "sb-form-radio-input",
  data() {
    return {
      selected: this.modelValue || this.value || null
    };
  },
  methods: {
    doSelect(e) {
      !this.disabled && !this.readOnly && (this.selected = e, this.$nextTick(() => {
        this.$emit("update:modelValue", this.selected), this.$emit("input", this.selected), this.$emit("change", this.selected);
      }));
    },
    handleErrorMessage() {
      return this.errorMessage ? typeof this.errorMessage == "string" ? this.errorMessage : this.errorMessage(this.selected) : "";
    },
    handleKeydown(e, a) {
      e.key === "Enter" && this.doSelect(a);
    },
    isSelected(e) {
      return this.selected && Object.keys(this.selected).length > 0 ? this.selected.value === e.value : !1;
    }
  },
  watch: {
    modelValue: {
      deep: !0,
      handler(e) {
        e ? this.selected = { ...e } : this.selected = null;
      }
    },
    value: {
      deep: !0,
      handler(e) {
        e ? this.selected = { ...e } : this.selected = null;
      }
    }
  }
});
const _ = (e) => (f("data-v-8ed5d4e6"), e = e(), m(), e), v = {
  key: 0,
  class: "asterisk"
}, q = ["tabindex", "onClick", "onKeydown"], k = /* @__PURE__ */ _(() => /* @__PURE__ */ t("div", { class: "selector" }, null, -1)), S = { class: "label" }, $ = {
  key: 1,
  class: "error-wrapper"
}, M = ["innerHTML"];
function O(e, a, E, w, B, C) {
  return s(), r("div", c({
    class: [{ error: e.isError }, "radio-wrapper"]
  }, { ...e.$attrs }), [
    e.label ? (s(), r("label", {
      key: 0,
      class: d(["label", { required: e.required }])
    }, [
      t("span", null, n(e.label), 1),
      e.required ? (s(), r("span", v, "*")) : i("", !0)
    ], 2)) : i("", !0),
    t("div", {
      class: d(["input-group radios-wrapper", { disabled: e.disabled, readonly: e.readOnly }])
    }, [
      (s(!0), r(h, null, y(e.list, (l, u) => (s(), r("div", {
        class: d([{
          disabled: e.disabled,
          readonly: e.readOnly,
          selected: e.isSelected(l)
        }, "radio"]),
        key: u,
        tabindex: !e.disabled && !e.readOnly ? 0 : -1,
        onClick: (o) => e.doSelect(l),
        onKeydown: (o) => e.handleKeydown(o, l)
      }, [
        k,
        t("p", S, n(l.label), 1)
      ], 42, q))), 128))
    ], 2),
    e.isError ? (s(), r("div", $, [
      t("span", {
        innerHTML: e.handleErrorMessage()
      }, null, 8, M)
    ])) : i("", !0)
  ], 16);
}
const I = /* @__PURE__ */ b(g, [["render", O], ["__scopeId", "data-v-8ed5d4e6"]]);
export {
  I as default
};

==> vue-sb-components-2.4.31.tgz: package/components/form-radio/form-radio.js <==
import "./form-radio.css";
import { defineComponent as u, openBlock as s, createElementBlock as r, mergeProps as p, normalizeClass as d, createElementVNode as t, toDisplayString as c, createCommentVNode as i, Fragment as h, renderList as y, pushScopeId as f, popScopeId as m } from "vue";
import { _ as b } from "../../_plugin-vue_export-helper-dad06003.js";
const g = u({
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    input: (e) => !0
  },
  props: {
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    isError: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    list: {
      required: !0,
      type: Object
    },
    modelValue: {
      required: !1,
      type: Object
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    value: {
      required: !1,
      type: Object
    }
  },
  name: "sb-form-radio-input",
  data() {
    return {
      selected: this.modelValue || this.value || null
    };
  },
  methods: {
    doSelect(e) {
      !this.disabled && !this.readOnly && (this.selected = e, this.$nextTick(() => {
        this.$emit("update:modelValue", this.selected), this.$emit("input", this.selected), this.$emit("change", this.selected);
      }));
    },
    handleErrorMessage() {
      return this.errorMessage ? typeof this.errorMessage == "string" ? this.errorMessage : this.errorMessage(this.selected) : "";
    },
    handleKeydown(e, a) {
      e.key === "Enter" && this.doSelect(a);
    },
    isSelected(e) {
      return this.selected && Object.keys(this.selected).length > 0 ? this.selected.value === e.value : !1;
    }
  },
  watch: {
    modelValue: {
      deep: !0,
      handler(e) {
        e ? this.selected = { ...e } : this.selected = null;
      }
    },
    value: {
      deep: !0,
      handler(e) {
        e ? this.selected = { ...e } : this.selected = null;
      }
    }
  }
});
const _ = (e) => (f("data-v-db31e8de"), e = e(), m(), e), v = {
  key: 0,
  class: "asterisk"
}, q = ["tabindex", "onClick", "onKeydown"], k = /* @__PURE__ */ _(() => /* @__PURE__ */ t("div", { class: "selector" }, null, -1)), M = ["innerHTML"], S = {
  key: 1,
  class: "error-wrapper"
}, $ = ["innerHTML"];
function O(e, a, E, w, B, C) {
  return s(), r("div", p({
    class: [{ error: e.isError }, "radio-wrapper"]
  }, { ...e.$attrs }), [
    e.label ? (s(), r("label", {
      key: 0,
      class: d(["label", { required: e.required }])
    }, [
      t("span", null, c(e.label), 1),
      e.required ? (s(), r("span", v, "*")) : i("", !0)
    ], 2)) : i("", !0),
    t("div", {
      class: d(["input-group radios-wrapper", { disabled: e.disabled, readonly: e.readOnly }])
    }, [
      (s(!0), r(h, null, y(e.list, (l, o) => (s(), r("div", {
        class: d([{
          disabled: e.disabled,
          readonly: e.readOnly,
          selected: e.isSelected(l)
        }, "radio"]),
        key: o,
        tabindex: !e.disabled && !e.readOnly ? 0 : -1,
        onClick: (n) => e.doSelect(l),
        onKeydown: (n) => e.handleKeydown(n, l)
      }, [
        k,
        t("p", {
          class: "label",
          innerHTML: l.label
        }, null, 8, M)
      ], 42, q))), 128))
    ], 2),
    e.isError ? (s(), r("div", S, [
      t("span", {
        innerHTML: e.handleErrorMessage()
      }, null, 8, $)
    ])) : i("", !0)
  ], 16);
}
const V = /* @__PURE__ */ b(g, [["render", O], ["__scopeId", "data-v-db31e8de"]]);
export {
  V as default
};
